@@ -84,7 +84,7 @@ def get_info_artikel(AID):
     """
     url = codex_vlaanderen_artid + str(AID)
     r = requests.get(url)
-    artikel_json = json.loads(r.content[1:len(r.content)-2].decode())
+    artikel_json = json.loads(r.content[1:len(r.content)-2].decode('utf8'))
     return {
         'ArtNr': artikel_json['ArtNr'],
         'ref': codex_vlaanderen_doc_url + str(artikel_json['DocumentID']) + codex_vlaanderen_art_posturl + str(AID)
@@ -123,12 +123,12 @@ def get_text_art(AID):
     """
     url_art = codex_vlaanderen_artid + str(AID)
     r = requests.get(url_art)
-    artikel_json = json.loads(r.content[1:len(r.content)-2].decode())
+    artikel_json = json.loads(r.content[1:len(r.content)-2].decode('utf8'))
     try:
         RecID = artikel_json['HistorischeVersies'][len(artikel_json['HistorischeVersies'])-1]['RecID']
         url_arthis = codex_vlaanderen_arthisid + str(RecID)
         r = requests.get(url_arthis)
-        return json.loads(r.content[1:len(r.content)-2].decode())['Tekst'].replace('<BR>', '|BR|')
+        return json.loads(r.content[1:len(r.content)-2].decode('utf8'))['Tekst'].replace('<BR>', '|BR|')
     except:
         return ""
 
@@ -157,6 +157,33 @@ class ArtikelTextDirective(Directive):
         node_latex = nodes.raw('', latex_input, format='latex')
         return [node_latex, node_html]
 
+class CollapsableVraagDirective(Directive):
+    """Directive to collapse text
+    """
+    required_arguments = 0
+    optional_arguments = 0
+    option_spec = dict(collapse=directives.flag)
+    option_spec['vraag'] = directives.unchanged_required  
+    option_spec['beschrijving'] = directives.unchanged_required
+
+    has_content = True
+
+    def run(self):
+        collapseclass= uuid.uuid4().hex
+        set_classes(self.options)
+        html_class = "collapsable collapstext"
+        html_input = '<dl class="%s"><input class="toggle-box" id="%s" type="checkbox"><label for="%s"> <dt class="title"><tt class="descname">%s</tt></dt></label><div class="textcontent"><dd class="description"><i> %s </i></dd><dd class="content"> %s </dd></div></dl>' \
+                     % (html_class, collapseclass, collapseclass, self.options['vraag'], self.options['beschrijving'], str(self.content[0]))
+        latex_line = r'\rule{\textwidth}{0.6pt}'
+        latex_input = r'\newline %s \textbf{Artikel:} %s %s'  \
+                      %(latex_line, self.content, latex_line)
+        node_html = nodes.raw('', html_input, format='html')
+        node_latex = nodes.raw('', latex_input, format='latex')
+        return [node_latex, node_html]
+
+
+
+
 def setup(app):
     """Install the plugin.
 
@@ -166,6 +193,7 @@ def setup(app):
     app.add_role('codex-doc', codex_role)
     app.add_role('codex-art', codex_role)
     app.add_directive("codex-art-text", ArtikelTextDirective)
+    app.add_directive("codex-vraag", CollapsableVraagDirective)
     app.add_config_value('codex_vlaanderen_url', codex_vlaanderen_url, 'env')
     app.add_config_value('codexws_vlaanderen_url', codexws_vlaanderen_url, 'env')
     app.add_config_value('codex_vlaanderen_doc_url', codex_vlaanderen_doc_url, 'env')
